/*
 ==============================================================================================================================
 Program : OSDBT
 Author  : Mike G7GTN 
 Email   : mikeg7gtn@gmail.com
 Version : 1.01
 IDE Ver : Ardunio 1.0.5
 Date    : 17/06/2014
 ==============================================================================================================================

 Purpose : To control a MinimOSD MAX7456 Based Module via eBay HC-06 Slave Bluetooth Module.
 	                                                                                                                       
                                                           
     OOOOOOOOO        SSSSSSSSSSSSSSS DDDDDDDDDDDDD        
   OO:::::::::OO    SS:::::::::::::::SD::::::::::::DDD     
 OO:::::::::::::OO S:::::SSSSSS::::::SD:::::::::::::::DD   
O:::::::OOO:::::::OS:::::S     SSSSSSSDDD:::::DDDDD:::::D  
O::::::O   O::::::OS:::::S              D:::::D    D:::::D 
O:::::O     O:::::OS:::::S              D:::::D     D:::::D
O:::::O     O:::::O S::::SSSS           D:::::D     D:::::D
O:::::O     O:::::O  SS::::::SSSSS      D:::::D     D:::::D
O:::::O     O:::::O    SSS::::::::SS    D:::::D     D:::::D
O:::::O     O:::::O       SSSSSS::::S   D:::::D     D:::::D
O:::::O     O:::::O            S:::::S  D:::::D     D:::::D
O::::::O   O::::::O            S:::::S  D:::::D    D:::::D 
O:::::::OOO:::::::OSSSSSSS     S:::::SDDD:::::DDDDD:::::D  
 OO:::::::::::::OO S::::::SSSSSS:::::SD:::::::::::::::DD   
   OO:::::::::OO   S:::::::::::::::SS D::::::::::::DDD     
     OOOOOOOOO      SSSSSSSSSSSSSSS   DDDDDDDDDDDDD        
                                                           
                                                                                                  
                                                                                                 
HHHHHHHHH     HHHHHHHHH      CCCCCCCCCCCCC                       000000000             66666666   
H:::::::H     H:::::::H   CCC::::::::::::C                     00:::::::::00          6::::::6    
H:::::::H     H:::::::H CC:::::::::::::::C                   00:::::::::::::00       6::::::6     
HH::::::H     H::::::HHC:::::CCCCCCCC::::C                  0:::::::000:::::::0     6::::::6      
  H:::::H     H:::::H C:::::C       CCCCCC                  0::::::0   0::::::0    6::::::6       
  H:::::H     H:::::HC:::::C                                0:::::0     0:::::0   6::::::6        
  H::::::HHHHH::::::HC:::::C                                0:::::0     0:::::0  6::::::6         
  H:::::::::::::::::HC:::::C               ---------------  0:::::0 000 0:::::0 6::::::::66666    
  H:::::::::::::::::HC:::::C               -:::::::::::::-  0:::::0 000 0:::::06::::::::::::::66  
  H::::::HHHHH::::::HC:::::C               ---------------  0:::::0     0:::::06::::::66666:::::6 
  H:::::H     H:::::HC:::::C                                0:::::0     0:::::06:::::6     6:::::6
  H:::::H     H:::::H C:::::C       CCCCCC                  0::::::0   0::::::06:::::6     6:::::6
HH::::::H     H::::::HHC:::::CCCCCCCC::::C                  0:::::::000:::::::06::::::66666::::::6
H:::::::H     H:::::::H CC:::::::::::::::C                   00:::::::::::::00  66:::::::::::::66 
H:::::::H     H:::::::H   CCC::::::::::::C                     00:::::::::00      66:::::::::66   
HHHHHHHHH     HHHHHHHHH      CCCCCCCCCCCCC                       000000000          666666666     
                                                                                                 
V1.01 Added Hard reset.
                             
                             Enter your required Captions / Callsigns starting from line #74 
                                                                                                                                         		
 ===============================================================================================================================
*/

// I/O Pins on Minim OSD Module
#define DATAOUT 11	        	// MOSI
#define DATAIN  12	        	// MISO
#define SPICLOCK 13	        	// SCK
#define MAX7456SELECT 6         	// SS 
#define MAX7456RESET 10    

#define BRIGHTNESS_ADDRESS 4  		// EEPROM address for Characters Brightness Level
#define PCTEST				// Show menu for PC Serial Terminal testing

#include "MAX7456osd.h"             	// Register names for MAX7456 device
#include <EEPROM.h>	            	// Read & Write to ATMEGA328P Eeprom

volatile int  incomingByte;             // For Serial Communications
char inkey;

// Set up your required captions here
char Caption1[] =  "G7GTN";
char Caption2[] =  "G7GTN 24CMs - ATV";
char Caption3[] =  "G7GTN TX 1249MHz";
char Caption4[] =  "G7GTN TX 1255MHz";
char Caption5[] =  "G7GTN 2.4GHz ATV";
char Caption6[] =  "G7GTN - 144.750MHz";
char Caption7[] =  "G7GTN TELEVISION";
char Caption8[] =  "G7GTN 10GHz ATV";
char Caption9[] =  "G7GTN TV";

//---------------------------------------------------------------------------------------
void setup()
{
  byte spi_junk;
 // int x;
 // int i;
  
  pinMode(MAX7456RESET,OUTPUT);
  digitalWrite(MAX7456RESET,HIGH); 
  
  pinMode(MAX7456SELECT,OUTPUT);
  digitalWrite(MAX7456SELECT,HIGH);  	              // Disable device

  pinMode(DATAOUT, OUTPUT);
  pinMode(DATAIN, INPUT);
  pinMode(SPICLOCK,OUTPUT);

  Serial.begin(9600);                                // Start Serial 
  Serial.flush();
  delay(100);

  #if defined PCTEST                                // Show Menu in terminal for PC serial --> TTL testing
       Serial.println("PC Terminal Test    ");
       Serial.println("--------------------");
       Serial.println(" 0 - Clear OSD.  1 - 9 Captions.");
       Serial.println(" B - Brightness                 ");
       Serial.println(" C - Show NVRAM character set   ");
       Serial.println(" R - Reset MAX7456 OSD Chip     ");
       Serial.println(" X - Clear Controllers Eeprom   "); 
   #endif

  // SPCR = 01010000
  //interrupt disabled,spi enabled,msb 1st,master,clk low when idle,
  //sample on leading edge of clk,system clock/4 rate (4 meg)
  SPCR = (1<<SPE)|(1<<MSTR);
  spi_junk=SPSR;
  spi_junk=SPDR;
  delay(250);
  
  // Force soft reset on Max7456
  digitalWrite(MAX7456SELECT,LOW);
  spi_transfer(VM0_reg);
  spi_transfer(MAX7456_RESET);
  digitalWrite(MAX7456SELECT,HIGH);
  delay(500);		

  // Set all rows to defined character white level, 90%
  //digitalWrite(MAX7456SELECT,LOW);
  //for (x = 0; x < MAX_screen_rows; x++)
  //{
  //  spi_transfer(x + 0x10);
  //  spi_transfer(WHITE_level_90);
  //}

  // Enable Max7456
  spi_transfer(VM0_reg);
  spi_transfer(VERTICAL_SYNC_NEXT_VSYNC);   
  spi_transfer(SYNC_MODE_AUTO);
  spi_transfer(VIDEO_MODE_PAL);
  spi_transfer(OSD_ENABLE); 	               	   
  digitalWrite(MAX7456SELECT,HIGH);
  delay(100);			     			    		    

  setBrightness(EEPROM.read(BRIGHTNESS_ADDRESS));	       // Check for user saved Brightness Level

  #if defined TEST
    OSD_write_to_screen("TEST",23,11,0,0);                     // Display if defined 
  #endif

  incomingByte = 0;

} 

//-------------------------------------------------------------------------------------------- All OSD Functions Follow
//
void Max7456()
{
  spi_transfer(VM0_reg);
  spi_transfer(VERTICAL_SYNC_NEXT_VSYNC);   
  spi_transfer(SYNC_MODE_AUTO);
  spi_transfer(VIDEO_MODE_PAL);
  spi_transfer(OSD_ENABLE); 	                	   
  digitalWrite(MAX7456SELECT,HIGH);
  delay(100);
}

//-------------------------------------------------------------------------------------------- ASCII Table Conversion
byte convert_ascii (int character)
{

 byte lookup_char;

  if (character == 32)
    lookup_char = 0x00; // blank space
  else if (character == 48)
    lookup_char = 0x0a; // 0
  else if ((character > 48) && (character < 58))
    lookup_char = (character - 48); // 1-9
  else if ((character > 64) && (character < 91))
    lookup_char = (character - 54); // A-Z
  else if ((character > 96) && (character < 123))
    lookup_char = (character - 60); // a-z
  else if (character == 34)
    lookup_char = 0x48; // "
  else if (character == 39)
    lookup_char = 0x46; // '
  else if (character == 40)
    lookup_char = 0x3f; // (
  else if (character == 41)
    lookup_char = 0x40; // )
  else if (character == 44)
    lookup_char = 0x45; // ,
  else if (character == 45)
    lookup_char = 0x49; // -
  else if (character == 46)
    lookup_char = 0x41; // .
  else if (character == 47)
    lookup_char = 0x47; // /
  else if (character == 58)
    lookup_char = 0x44; // :
  else if (character == 59)
    lookup_char = 0x43; // ;
  else if (character == 60)
    lookup_char = 0x4a; // <
  else if (character == 62)
    lookup_char = 0x4b; // >
  else if (character == 63)
    lookup_char = 0x42; // ?
  else if (character == 64)
    lookup_char = 0x4c; // @
  else
    lookup_char = 0x00; // out of range, blank space

 return (lookup_char);
}

//-------------------------------------------------------------------------------------------- OSD Clear Screen
//
void OSD_Clear()
{
  digitalWrite(MAX7456SELECT,LOW);
  spi_transfer(DMM_reg);
  spi_transfer(CLEAR_display);      
  digitalWrite(MAX7456SELECT,HIGH);
}

//-------------------------------------------------------------------------------------------- Write Text string to screen
// Text to display, X position, Y position, Blink Text, Invert Text
//
void OSD_write_to_screen(const char s[], byte x, byte y, byte blink, byte invert)
{  
  unsigned int linepos;
  byte local_count;
  byte settings, char_address_hi, char_address_lo;
  byte screen_char;
  
  local_count = 0;
  
  char_address_hi = 0;
  char_address_lo = 0;
  
  // convert X,Y to line position
  linepos = y*30+x;

  // divide in to hi & lo byte
  char_address_hi = linepos >> 8;
  char_address_lo = linepos;

  settings = B00000001;

  // set blink bit
  if (blink) {
    settings |= (1 << 4);	 // forces nth bit of x to be 1.  all other bits left alone.
  }
  // set invert bit
  if (invert){
    settings |= (1 << 3);	 // forces nth bit of x to be 1.  all other bits left alone.
  }

  digitalWrite(MAX7456SELECT,LOW);

  spi_transfer(DMM_reg);         //dmm
  spi_transfer(settings);

  spi_transfer(DMAH_reg);        // set start address high
  spi_transfer(char_address_hi);

  spi_transfer(DMAL_reg);       // set start address low
  spi_transfer(char_address_lo);

  while(s[local_count]!='\0')   // write out full screen
  {
    screen_char = s[local_count];
    screen_char= convert_ascii(screen_char);
    spi_transfer(DMDI_reg);
    spi_transfer(screen_char);
    local_count++;
  }
  
  spi_transfer(DMDI_reg);
  spi_transfer(END_string);

  spi_transfer(VM0_reg); // turn on screen next vertical. 
  spi_transfer(ENABLE_display_vert);
  digitalWrite(MAX7456SELECT,HIGH);  
  }

// -------------------------------------------------------------------------------------------- TV Typewriter Effect
// Print text one character at a time
void OSD_Rollout(const char s[], byte x, byte y, byte blink, byte invert) {
  byte j = 0;
  char temp[2];

  temp[1] = '\0';

  while(s[j]!='\0')             // write out full screen
  {  
    temp[0] = s[j];
    OSD_write_to_screen(temp,x+j,y,blink,invert);
    j++;
    delay(310);                // Change to lower delay for faster effect
  }
}

// -------------------------------------------------------------------------------------------- Print MAX7456 NVRAM Character from supplied Hex code
// First byte is the HEX code, X Position, Y Position, Blink Char, Invert Char
// Example: -           
//
//                  printMax7456Char(0xF9,5,6,0,0);    // Speaker Icon

void printMax7456Char(const byte address, byte x, byte y, byte blink, byte inv)
{
	byte ad = address;
	OSD_printchrs(&ad,1,x,y,blink,inv);
}

void OSD_printchrs(byte chars[],byte size, byte x, byte y, byte blink, byte invert)
{
  
  unsigned int linepos;
  byte local_count;
  byte settings, char_address_hi, char_address_lo;
 // byte screen_char;
  byte currentCharMax7456;

  local_count = 0;
  
  char_address_hi = 0;
  char_address_lo = 0;
  
  // convert X,Y to line position
  linepos = y*30+x;

  // divide in to hi & lo byte
  char_address_hi = linepos >> 8;
  char_address_lo = linepos;

  settings = B00000001;

  // set blink bit
  if (blink) {
    settings |= (1 << 4);	               // forces nth bit of x to be 1.  all other bits left alone.
  }
  // set invert bit
  if (invert){
    settings |= (1 << 3);	               // forces nth bit of x to be 1.  all other bits left alone.
  }

  digitalWrite(MAX7456SELECT,LOW);

  spi_transfer(DMM_reg);                       //dmm
  spi_transfer(settings);

  spi_transfer(DMAH_reg);                      // set start address high
  spi_transfer(char_address_hi);

  spi_transfer(DMAL_reg);                      // set start address low
  spi_transfer(char_address_lo);

  for(int i = 0; i < size ; i++)
  {
    currentCharMax7456 = chars[i];
    spi_transfer(DMDI_reg);
    spi_transfer(currentCharMax7456);
  }

  spi_transfer(DMDI_reg);
  spi_transfer(END_string);

  spi_transfer(VM0_reg);                       // turn on screen next vertical. 
  spi_transfer(ENABLE_display_vert);
  digitalWrite(MAX7456SELECT,HIGH);
  
  }

//-------------------------------------------------------------------------------------------- Show NVRAM Character Set
// Displays the Font set we have loaded into the NVRAM area
void showcharset()
{
unsigned short x;

  // clear the screen
  digitalWrite(MAX7456SELECT,LOW);
  spi_writereg(DMM_reg,CLEAR_display);
  digitalWrite(MAX7456SELECT,HIGH);
  delay(1); 				// clearing display takes 20uS 
  // disable display
  digitalWrite(MAX7456SELECT,LOW);

  spi_writereg(DMM_reg,0x01); 		// 16 bit trans w/o background, autoincrement
  spi_writereg(DMAH_reg,0); 		// set start address high
  spi_writereg(DMAL_reg,33); 		// set start address low (line 1 col 3 (0 based)

  // show all characters on screen 
  for (x = 0;x<255;x++) {
    spi_writereg(DMDI_reg,(byte)x);
    if ((x%24)==23) {
      for (byte i=0;i<6;i++) spi_writereg(DMDI_reg,0);
    }
  }

  spi_writereg(DMDI_reg,END_string);

  // spi_writereg(VM0_reg,ENABLE_display_vert);  // turn on screen next vertical
  digitalWrite(MAX7456SELECT,HIGH);
} 

//-------------------------------------------------------------------------------------------- Software reset OSD
//
void reset_max7456()
{
// int x;  
  // force soft reset on Max7456
  digitalWrite(MAX7456SELECT,LOW);
  spi_transfer(VM0_reg);
  spi_transfer(MAX7456_reset);
  digitalWrite(MAX7456SELECT,HIGH);
  delay(500);	           		

  // make sure the Max7456 is enabled
  spi_transfer(VM0_reg);
  spi_transfer(ENABLE_display);
  digitalWrite(MAX7456SELECT,HIGH);
}

//--------------------------------------------------------------------------------------------
//
void spi_writereg(byte r, byte d) {
  spi_transfer(r);
  spi_transfer(d);
}  

//--------------------------------------------------------------------------------------------
//
byte spi_transfer(volatile byte data)
{
  SPDR = data;			  // Start the transmission
  while (!(SPSR & (1<<SPIF)))     // Wait for the end of transmission
  {
  };
  return SPDR;			  // return the received byte
}

//--------------------------------------------------------------------------------------- On decoded IR select appropriate Caption based on HEX button value.
// Text to print, Location X, Location Y, Blink Text, Invert Text
void caption1()
{
   OSD_Clear(); 
   OSD_write_to_screen(Caption1, 3, 2, 0,0);    // NORMAL ASCII TEXT 
   printMax7456Char(0xA7,9,2,0,0);              // SAT DISH ICON 
}

void caption2()
{
   OSD_Clear(); 
   OSD_write_to_screen(Caption2, 3, 12, 0,0);   
} 

void caption3()
{
  OSD_Clear(); 
  OSD_write_to_screen(Caption3, 2, 4, 0,0);   
} 

void caption4()
{
   OSD_Clear();  
   OSD_write_to_screen(Caption4, 2, 6, 0,0);   
} 

void caption5()
{
   OSD_Clear(); 
   OSD_write_to_screen(Caption5, 2, 8, 0,0);   
} 

void caption6()
{
   OSD_Clear(); 
   OSD_write_to_screen(Caption6, 6, 10, 0,1);   
} 

void caption7()
{
   OSD_Clear();  
   OSD_write_to_screen(Caption7, 2, 12, 0,0);   
} 

void caption8()
{
   OSD_Clear(); 
   OSD_write_to_screen(Caption8, 6, 13, 0,1);   
} 

void caption9()
{
  OSD_Clear(); 
  OSD_Rollout(Caption9, 2, 3, 0,0);             // Display character one letter at a time
  printMax7456Char(0xA7,11,3,0,0);              // Sat Dish Icon 
}
                                                                                                                     
//--------------------------------------------------------------------------------------- Character Brightness Level Expressed as a % percentage                                                                          
//                                                                                                
void setBrightness(uint8_t level)
{
  // If EEPROM is unwritten (0xFF)
  if (level==255)
     Brightness90();      
  switch(level)
  {
    case 0:
      Brightness80();                  // Percentage 80%
      break;
    case 1:
      Brightness90();                  // Percentage 90%
      break;
    case 2:
      Brightness100();                 // Percentage 100%
      break;
    case 3:
      Brightness120();                 // Percentage 120%
      break;
  }
  
  if ((level>=0)&&(level<=3))
    EEPROM.write(BRIGHTNESS_ADDRESS, level);
}

// Set to user text brightness level                                                                                                                                            
void Brightness80()
{
int x;
int level;
  // Set all rows to same character white level, 80%
  digitalWrite(MAX7456SELECT,LOW);
  for (x = 0; x < MAX_screen_rows; x++)
  {
    spi_transfer(x + 0x10);
    spi_transfer(WHITE_level_80);
  }
    // Save level to Eeprom
    level=0;
    EEPROM.write(BRIGHTNESS_ADDRESS, level);  
}  

void Brightness90()
{
int x;
int level;
  // Set all rows to same character white level, 80%
  digitalWrite(MAX7456SELECT,LOW);
  for (x = 0; x < MAX_screen_rows; x++)
  {
    spi_transfer(x + 0x10);
    spi_transfer(WHITE_level_90);
  }  
    level=1;
    EEPROM.write(BRIGHTNESS_ADDRESS, level);  
} 

void Brightness100()
{
int x;
int level;
  // Set all rows to same character white level, 80%
  digitalWrite(MAX7456SELECT,LOW);
  for (x = 0; x < MAX_screen_rows; x++)
  {
    spi_transfer(x + 0x10);
    spi_transfer(WHITE_level_100);
  }
    level=2;
    EEPROM.write(BRIGHTNESS_ADDRESS, level);
} 
  
void Brightness120()
{
int x;
int level;
  // Set all rows to same character white level, 80%
  digitalWrite(MAX7456SELECT,LOW);
  for (x = 0; x < MAX_screen_rows; x++)
  {
    spi_transfer(x + 0x10);
    spi_transfer(WHITE_level_120);
  }  
    level=3;
    EEPROM.write(BRIGHTNESS_ADDRESS, level); 
}   

//--------------------------------------------------------------------------------------- About Screen
void about()
{  
  OSD_Clear(); 
  printMax7456Char(0xD7,2,1,0,0);             	     // Corner
  OSD_write_to_screen("MAX7456 OSD MODULE", 6, 2, 0,0);  
  printMax7456Char(0xD8,27,1,0,0);		     // Corner
  printMax7456Char(0xDB,5,3,0,0);
  printMax7456Char(0xDC,6,3,0,0);
  printMax7456Char(0xDC,7,3,0,0);
  printMax7456Char(0xDC,8,3,0,0);
  printMax7456Char(0xDC,9,3,0,0);
  printMax7456Char(0xDC,10,3,0,0);
  printMax7456Char(0xDC,11,3,0,0);
  printMax7456Char(0xDC,12,3,0,0);
  printMax7456Char(0xDC,13,3,0,0);
  printMax7456Char(0xDC,14,3,0,0);
  printMax7456Char(0xDC,15,3,0,0);
  printMax7456Char(0xDC,16,3,0,0);
  printMax7456Char(0xDC,17,3,0,0);
  printMax7456Char(0xDC,18,3,0,0);
  printMax7456Char(0xDC,19,3,0,0);
  printMax7456Char(0xDC,20,3,0,0);
  printMax7456Char(0xDC,21,3,0,0);
  printMax7456Char(0xDC,22,3,0,0);
  printMax7456Char(0xDC,23,3,0,0);
  printMax7456Char(0xDD,24,3,0,0);
  OSD_write_to_screen("BLUETOOTH CONTROLLER", 4, 5, 0,0);
  OSD_write_to_screen("CONTROL VIA CUSTOM", 4, 7, 0,0);
  OSD_write_to_screen("ANDROID APPLICATION", 5, 9, 0,0);
  OSD_write_to_screen("USES HC-06 MODULE", 5, 11, 0,0);
  printMax7456Char(0xA7,24,13,0,0);		     // Sat Icon
  printMax7456Char(0xDA,2,14,0,0);		     // Corner	
  printMax7456Char(0xD9,27,14,0,0);		     // Corner
}  

//--------------------------------------------------------------------------------------- Clear memory locations
// This routine really only needs to be run once to clean the whole Eeprom space.
void ClearEeprom()
{
  OSD_Clear();
  OSD_write_to_screen("Memory Clear", 6, 2, 0,0);   
  OSD_write_to_screen("Eeprom memory is being", 3, 4, 0,0); 
  OSD_write_to_screen("Cleared....", 3, 5, 0,0);
  // write zero to all 512 bytes of the ATMEGA328 EEPROM
  for (int i = 0; i < 512; i++)
    EEPROM.write(i, 0);
  OSD_write_to_screen("Completed", 3, 7, 0,0);   
}

//--------------------------------------------------------------------------------------- Hardreset
// Needed to allow to start looking for Serial on disconnect
void(* resetFunc) (void) = 0; //declare reset function @ address 0

//--------------------------------------------------------------------------------------- Bluetooth Serial Loop
// ASCII Commands are sent from the Android Application.
void GetSerial()
{
    while (Serial.available() > 0)        
  {
    // read the incoming byte:
    incomingByte = Serial.read();
    
    switch(incomingByte)
    {
      case 0X30:                                // ASCII "0" Clear OSD
        OSD_Clear();		        
      break;
      case 0X31:                                // ASCII "1" Show Caption 1                                    
        caption1(); 
      break;
      case 0X32:                                // ASCII "2" Show Caption 2
        caption2();
      break;
      case 0X33:                                // ASCII "3" Show Caption 3
       caption3(); 
      break;
      case 0X34:                                // ASCII "4" Show Caption 4
       caption4();
      break;
      case 0X35:                                // ASCII "5" Show Caption 5
        caption5();
      break;
      case 0X36:                                // ASCII "6" Show Caption 6
        caption6();
      break;
      case 0X37:                                // ASCII "7" Show Caption 7
       caption7();
      break;
      case 0X38:                                // ASCII "8" Show Caption 8
        caption8();
      break;
      case 0X39:                                // ASCII "9" Teletype Effect
        caption9();
      break;
      case 0X3A:                                // ASCII ":" Brightness Level 120%
        Brightness80(); 
      break;
      case 0X3B:                                // ASCII ";" Brightness Level 120%
        Brightness90(); 
      break;
      case 0X3C:                                // ASCII "<" Brightness Level 120%
        Brightness100(); 
      break;
      case 0X3D:                                // ASCII "=" Brightness Level 120%
        Brightness120(); 
      break;
      case 0X43:                                // ASCII "C" Show Character Set
        showcharset();
      break; 
      case 0X52:                                // ASCII "R" Reset OSD
        reset_max7456();
      break;  
      case 0X58:                                // ASCII "X" Clear Eeprom Memory
        OSD_Clear();
        ClearEeprom();
      break;       
      case 0X3F:                                // ASCII "?" Show About
        about();                          
      break;
      case 0X48:                                // ASCII "H" Hardreset
        resetFunc();                            // Call reset                          
      break;
   } 
 } 
} 
  
//--------------------------------------------------------------------------------------- Main Loop
void loop()
{
  GetSerial();                                      // Run our Serial Input routine 
}

